@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.429';
+our $VERSION = '2017.430';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -179,7 +179,7 @@ sub makePath($)
 
 sub fileList($)
  {my ($pattern) = @_;
-  bsd_glob($pattern)
+  bsd_glob($pattern, GLOB_MARK | GLOB_TILDE)
  }
 
 #-------------------------------------------------------------------------------
